@@ -875,10 +875,8 @@ static netwib_err netwib_priv_fmt_append_uint(netwib_bool usemax,
   netwib_string pout;
   netwib_uint32 nbdigit, nbzeroes, c32, base32;
   netwib_uint64 zero;
-  netwib_cmp cmp;
 
-  netwib_er(netwib_uint64_init_uint32(0, &zero));
-  netwib_er(netwib_uint64_cmp(ui64, zero, &cmp));
+  netwib__uint64_init_uint32(0, zero);
 
   nbdigit = 0;
   base32 = ps->base;
@@ -897,14 +895,14 @@ static netwib_err netwib_priv_fmt_append_uint(netwib_bool usemax,
       localarray[nbdigit++] = c;
       uimax = uidivbase;
     } while (uimax != 0);
-  } else if (!usemax && cmp != NETWIB_CMP_EQ) {
-    netwib_uint64 base64, uidivbase, uidivbaseperbase, c64;
-    netwib_er(netwib_uint64_init_uint32(base32, &base64));
+  } else if (!usemax && netwib__uint64_cmp_ne(ui64, zero)) {
+    netwib_uint64 base64, uidivbase, uidivbaseperbase, c64, remainder;
+    netwib__uint64_init_uint32(base32, base64);
     do {
-      netwib_er(netwib_uint64_div(ui64, base64, &uidivbase, NULL));
-      netwib_er(netwib_uint64_mul(uidivbase, base64, &uidivbaseperbase));
-      netwib_er(netwib_uint64_sub(ui64, uidivbaseperbase, &c64));
-      netwib_er(netwib_uint32_init_uint64(c64, &c32));
+      netwib__uint64_div(ui64, base64, &uidivbase, &remainder);
+      netwib__uint64_mul(uidivbase, base64, &uidivbaseperbase);
+      netwib__uint64_sub(ui64, uidivbaseperbase, c64);
+      netwib__uint32_init_uint64(c64, c32);
       if (ps->base == 17) {
         c = netwib_c2_16toC(c32);
       } else {
@@ -912,8 +910,7 @@ static netwib_err netwib_priv_fmt_append_uint(netwib_bool usemax,
       }
       localarray[nbdigit++] = c;
       ui64 = uidivbase;
-      netwib_er(netwib_uint64_cmp(ui64, zero, &cmp));
-    } while (cmp != NETWIB_CMP_EQ);
+    } while (netwib__uint64_cmp_ne(ui64, zero));
   } else {
     localarray[nbdigit++] = '0';
   }
@@ -998,19 +995,22 @@ static netwib_err netwib_priv_fmt_append_int(netwib_bool usemax,
   netwib_uint64 ui64, zero;
   netwib_cmp cmp;
 
-  netwib_er(netwib_uint64_init_uint32(0, &ui64));
+  netwib__uint64_init_uint32(0, ui64);
 
+  cmp = NETWIB_CMP_LT;
   if (usemax) {
     if (imax == 0) {
       cmp = NETWIB_CMP_EQ;
-    } else if (imax < 0) {
-      cmp = NETWIB_CMP_LT;
-    } else {
+    } else if (imax > 0) {
       cmp = NETWIB_CMP_GT;
     }
   } else {
-    netwib_er(netwib_uint64_init_uint32(0, &zero));
-    netwib_er(netwib_int64_cmp(i64, zero, &cmp));
+    netwib__uint64_init_uint32(0, zero);
+    if (netwib__int64_cmp_eq(i64, zero)) {
+      cmp = NETWIB_CMP_EQ;
+    } else if (netwib__int64_cmp_gt(i64, zero)) {
+      cmp = NETWIB_CMP_GT;
+    }
   }
 
   /* eventually put a sign */
@@ -1019,7 +1019,7 @@ static netwib_err netwib_priv_fmt_append_int(netwib_bool usemax,
     if (usemax) {
       uimax = (netwib_uintmax)-imax;
     } else {
-      netwib_er(netwib_int64_neg(i64, (netwib_int64*)&ui64));
+      netwib__int64_neg(i64, ui64);
     }
     /* put a '-' */
     array[0] = '-';
@@ -1880,7 +1880,6 @@ static netwib_err netwib_priv_fmt_decode_uint64(netwib_constbuf *pbuf,
   netwib_uint64 base64, number, number2, c64;
   netwib_uint32 c32;
   netwib_string pc;
-  netwib_cmp cmp;
   netwib_char c;
 
   /* obtain a reference to the string */
@@ -1919,8 +1918,8 @@ static netwib_err netwib_priv_fmt_decode_uint64(netwib_constbuf *pbuf,
   }
 
   /* loop and store in number */
-  netwib_er(netwib_uint64_init_uint32(0, &number));
-  netwib_er(netwib_uint64_init_uint32(base, &base64));
+  netwib__uint64_init_uint32(0, number);
+  netwib__uint64_init_uint32(base, base64);
   while(NETWIB_TRUE) {
     c = *pc++;
     if (c == '\0') {
@@ -1932,11 +1931,10 @@ static netwib_err netwib_priv_fmt_decode_uint64(netwib_constbuf *pbuf,
     if (c32 >= base) {
       return(NETWIB_ERR_PAINT);
     }
-    netwib_er(netwib_uint64_init_uint32(c32, &c64));
-    netwib_er(netwib_uint64_mul(number, base64, &number2));
-    netwib_er(netwib_uint64_add(number2, c64, &number2));
-    netwib_er(netwib_uint64_cmp(number2, number, &cmp));
-    if (cmp == NETWIB_CMP_LT) {
+    netwib__uint64_init_uint32(c32, c64);
+    netwib__uint64_mul(number, base64, &number2);
+    netwib__uint64_add(number2, c64, number2);
+    if (netwib__uint64_cmp_lt(number2, number)) {
       /* an overflow occurred */
       return(NETWIB_ERR_PAINT);
     }
@@ -1954,7 +1952,7 @@ static netwib_err netwib_priv_fmt_decode_int64(netwib_constbuf *pbuf,
   netwib_buf buf;
   netwib_data data;
   netwib_uint32 datasize;
-  netwib_uint64 ui64;
+  netwib_uint64 ui64, maxint64;
   netwib_bool ispos;
 
   datasize = netwib__buf_ref_data_size(pbuf);
@@ -1980,19 +1978,17 @@ static netwib_err netwib_priv_fmt_decode_int64(netwib_constbuf *pbuf,
   /* decode an unsigned */
   netwib_er(netwib_buf_init_ext_datafilled(data, datasize, &buf));
   netwib_er(netwib_priv_fmt_decode_uint64(&buf, 10, &ui64));
+  netwib__uint64_init_32(0x80000000u, 0, maxint64);
   if (ispos) {
-    netwib_er(netwib_int64_init_uint64(ui64, pnumber));
+    if (netwib__uint64_cmp_gt(ui64, maxint64)) {
+      return(NETWIB_ERR_PATOOHIGH);
+    }
+    *pnumber = ui64;
   } else {
-   #if NETWIB_INT64_FAKE == 0
-    if (ui64 > NETWIB_UINT_LL(0x8000000000000000)) {
+    if (netwib__uint64_cmp_gt(ui64, maxint64)) {
       return(NETWIB_ERR_PATOOLOW);
     }
-   #else
-    if (ui64.high > 0x80000000u) {
-      return(NETWIB_ERR_PATOOLOW);
-    }
-   #endif
-    netwib_er(netwib_int64_neg((netwib_int64)ui64, pnumber));
+    netwib__int64_neg(ui64, *pnumber);
   }
 
   return(NETWIB_ERR_OK);
@@ -2236,8 +2232,8 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
 
   /* initialize for integer conversions */
   ret = NETWIB_ERR_OK;
-  netwib_er(netwib_uint64_init_uint32(0, &ui64));
-  netwib_er(netwib_int64_init_int32(0, &i64));
+  netwib__uint64_init_uint32(0, ui64);
+  netwib__int64_init_int32(0, i64);
   switch(pscanitem->fmtinfos.fieldtype) {
     case NETWIB_PRIV_FMT_FIELDTYPE_UINT32 :
     case NETWIB_PRIV_FMT_FIELDTYPE_UINT16 :
@@ -2270,7 +2266,7 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
 #if NETWIB_INTPTR_BITS == 64
       ret = netwib_priv_fmt_decode_uint64(&localbuf, 16, &ui64);
       if (ret == NETWIB_ERR_OK) {
-        ret = netwib_uintptr_init_uint64(ui64, &uiptr);
+        netwib__uintptr_init_uint64(ui64, uiptr);
       }
 #else
       ret = netwib_priv_fmt_decode_uint32(&localbuf, 16,
@@ -2343,10 +2339,10 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
       }
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_UINTMAX :
-      ret = netwib_uintmax_init_uint64(ui64, (netwib_uintmax*)pscanitem->ptr);
+      netwib__uintmax_init_uint64(ui64, *(netwib_uintmax*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_UINTPTR :
-      ret = netwib_uintptr_init_uint64(ui64, (netwib_uintptr*)pscanitem->ptr);
+      netwib__uintptr_init_uint64(ui64, *(netwib_uintptr*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_INT32 :
       {
@@ -2385,10 +2381,10 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
       }
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_INTMAX :
-      ret = netwib_intmax_init_int64(i64, (netwib_intmax*)pscanitem->ptr);
+      netwib__intmax_init_int64(i64, *(netwib_intmax*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_INTPTR :
-      ret = netwib_intptr_init_int64(ui64, (netwib_intptr*)pscanitem->ptr);
+      netwib__intptr_init_int64(ui64, *(netwib_intptr*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_BOOL :
       ret = netwib_priv_fmt_decode_bool(&localbuf,
