@@ -292,6 +292,7 @@ netwib_err netwib_ring_del_criteria(netwib_ring *pring,
       break;
     }
     if (pfunc_criteria != NULL) {
+      b = NETWIB_FALSE;
       ret = (*pfunc_criteria)(pwork2->pitem, pinfos, &b);
       if (ret != NETWIB_ERR_OK) {
         /* do not unlink the item */
@@ -367,6 +368,7 @@ netwib_err netwib_ring_del_duplicate(netwib_ring *pring,
       if (pworkb2 == (netwib_ringitem*)pring) {
         break;
       }
+      cmp = NETWIB_CMP_LT;
       ret = (*pfunc_compare) (pworka->pitem, pworkb2->pitem, pinfos, &cmp);
       if (ret != NETWIB_ERR_OK) {
         /* do not unlink the item */
@@ -485,6 +487,7 @@ netwib_err netwib_ring_sort(netwib_ring *pring,
           if (l1size == 0) return(NETWIB_ERR_LOINTERNALERROR);
           comefroml1 = NETWIB_TRUE;
         } else {
+          cmp = NETWIB_CMP_LT;
           ret = (*pfunc_compare)(pl1->pitem, pl2->pitem, pinfos, &cmp);
           if (ret != NETWIB_ERR_OK) {
             /* need to relink the ring */
@@ -578,6 +581,7 @@ netwib_err netwib_ring_group(netwib_ring *pring,
       if (pworkb2 == (netwib_ringitem*)pring) {
         break;
       }
+      cmp = NETWIB_CMP_LT;
       ret = (*pfunc_compare) (pworka->pitem, pworkb2->pitem, pinfos, &cmp);
       if (ret != NETWIB_ERR_OK) {
         /* do not unlink the item */
