@@ -1,6 +1,12 @@
 /* This file is part of Netwib.
 */
 
+/*-------------------------------------------------------------*/
+#define SNIFF_TCPREORD_TIMEOUT 30 /* in seconds */
+#define SNIFF_TCPREORD_NEWITEMS_CLEAN  10 /* clean hash after such new items */
+#define SNIFF_TCPREORD_PKT_CLEAN  1000 /* clean hash after such packets */
+#define SNIFF_TCPREORD_SEQNUM_WINDOW 100000 /* window of valid seqnum */
+
 /*-------------------------------------------------------------*/
 static netwib_err sniff_tcp_expectedseqnum(netwib_consttcphdr *ptcphdr,
                                            netwib_constbuf *ptcpdata,
@@ -23,15 +29,16 @@ static netwib_err sniff_tcp_checksynchro(netwib_uint32 seqnum,
 {
   *psynchro = NETWIB_TRUE;
 
-#define SNIFF_TCP_SEQNUM_SYNCHRO 100000
-
-  if (expectedseqnum <= 0xFFFFFFFFu - SNIFF_TCP_SEQNUM_SYNCHRO) {
-    if (seqnum > expectedseqnum+SNIFF_TCP_SEQNUM_SYNCHRO ||
+  if (expectedseqnum <= 0xFFFFFFFFu - SNIFF_TCPREORD_SEQNUM_WINDOW) {
+    if (seqnum > (netwib_uint32)(expectedseqnum+SNIFF_TCPREORD_SEQNUM_WINDOW)
+        || /*or*/
         seqnum < expectedseqnum) {
       *psynchro = NETWIB_FALSE;
     }
   } else {
-    if (seqnum > expectedseqnum+SNIFF_TCP_SEQNUM_SYNCHRO &&
+    /* this sum will overflow ; this is normal */
+    if (seqnum > (netwib_uint32)(expectedseqnum+SNIFF_TCPREORD_SEQNUM_WINDOW)
+        && /*and*/
         seqnum < expectedseqnum) {
       *psynchro = NETWIB_FALSE;
     }
@@ -43,11 +50,15 @@ static netwib_err sniff_tcp_checksynchro(netwib_uint32 seqnum,
 
 /*-------------------------------------------------------------*/
 /*-------------------------------------------------------------*/
+/* Rings will contain each TCP fragment which are not yet
+   synchronized.
+   Following functions manage one ring item.
+*/
 
 /*-------------------------------------------------------------*/
 typedef struct {
-  netwib_uint32 seqnum;
-  netwib_uint32 nextexpectedseqnum;
+  netwib_uint32 seqnum; /* sequence number of first byte in pkt */
+  netwib_uint32 nextexpectedseqnum; /* seqnum of last byte */
   netwib_buf pkt;
 } sniff_tcp_ringitem;
 
@@ -88,23 +99,28 @@ static netwib_err sniff_tcp_ringitem_erase(netwib_ptr pitem)
 
 /*-------------------------------------------------------------*/
 /*-------------------------------------------------------------*/
+/* Hashes will contain each ring described above.
+   Following functions manage one hash item.
+   Each hash item has for key: IP_src+IP_dst+PORT_src+PORT_dst.
+*/
 
 /*-------------------------------------------------------------*/
 typedef struct {
-  netwib_uint32 lastupdate;
-  netwib_uint32 expectedseqnum;
-  netwib_bool ringreadytouse;
-  netwib_ring *pring;
+  netwib_uint32 expireat; /* updated on each packet received for this session*/
+  netwib_uint32 expectedseqnum; /* next expected seqnum for this session */
+  netwib_bool ringreadytouse; /* ring is not initialized before there is
+                                 one out of order TCP packet */
+  netwib_ring *pring; /* ring of out of order TCP packets */
   netwib_ring_index *pringindex;
 } sniff_tcp_hashitem;
 
 /*-------------------------------------------------------------*/
-#define SNIFF_TCP_HASHITEM_KEY_LEN 40
+#define SNIFF_TCP_HASHITEM_KEY_MAXLEN 40
 static netwib_err sniff_tcp_hashitem_key(netwib_constiphdr *piphdr,
                                          netwib_consttcphdr *ptcphdr,
                                          netwib_buf *pkey)
 {
-  netwib_byte array[SNIFF_TCP_HASHITEM_KEY_LEN];
+  netwib_byte array[SNIFF_TCP_HASHITEM_KEY_MAXLEN];
   netwib_data data;
 
   data = array;
@@ -114,7 +130,7 @@ static netwib_err sniff_tcp_hashitem_key(netwib_constiphdr *piphdr,
     netwib__data_append_uint32(data, piphdr->dst.ipvalue.ip4);
     netwib__data_append_uint16(data, ptcphdr->src);
     netwib__data_append_uint16(data, ptcphdr->dst);
-    netwib_er(netwib_buf_append_data(array, 12, pkey));
+    netwib_er(netwib_buf_append_data(array, 1+2*NETWIB_IP4_LEN+4, pkey));
   } else {
     netwib__data_append_uint8(data, NETWIB_IPTYPE_IP6);
     netwib_c_memcpy(data, piphdr->src.ipvalue.ip6.b, NETWIB_IP6_LEN);
@@ -161,6 +177,9 @@ static netwib_err sniff_tcp_hashitem_erase(netwib_ptr pitem)
 }
 
 /*-------------------------------------------------------------*/
+/* to remove items which are too old
+   Instead of removing them, we could send them.
+ */
 static netwib_err sniff_tcp_hashitem_clean(netwib_constbuf *pkey,
                                            netwib_constptr pitem,
                                            netwib_ptr pinfos,
@@ -169,13 +188,13 @@ static netwib_err sniff_tcp_hashitem_clean(netwib_constbuf *pkey,
   netwib_uint32 *psec = (netwib_uint32 *)pinfos;
   const sniff_tcp_hashitem *psthi = (const sniff_tcp_hashitem *)pitem;
 
-  if (*psec > psthi->lastupdate) {
+  if (*psec > psthi->expireat) {
     *pbool = NETWIB_TRUE;
   } else {
     *pbool = NETWIB_FALSE;
   }
+  pkey = pkey; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pkey = pkey;
 }
 
 /*-------------------------------------------------------------*/
@@ -189,7 +208,7 @@ static netwib_err sniff_tcp_hashitem_update(sniff_tcp_hashitem *psthi,
                                      &psthi->expectedseqnum));
 
   netwib_er(netwib_time_init_now(&t));
-  psthi->lastupdate = t.sec;
+  psthi->expireat = t.sec + SNIFF_TCPREORD_TIMEOUT;
 
   return(NETWIB_ERR_OK);
 }
@@ -203,7 +222,6 @@ static netwib_err sniff_tcp_hashitem_add_packet(sniff_tcp_hashitem *psthi,
   netwib_uint32 nextexpectedseqnum;
   netwib_ptr pitem;
   netwib_bool issynchro;
-  netwib_time t;
 
   /* first, check if this packet is synchronized */
   netwib_er(sniff_tcp_checksynchro(ptcphdr->seqnum, psthi->expectedseqnum,
@@ -218,6 +236,7 @@ static netwib_err sniff_tcp_hashitem_add_packet(sniff_tcp_hashitem *psthi,
     netwib_er(netwib_ring_init(&sniff_tcp_ringitem_erase, NULL,
                                &psthi->pring));
     netwib_er(netwib_ring_index_init(psthi->pring, &psthi->pringindex));
+    psthi->ringreadytouse = NETWIB_TRUE;
   }
 
   /* add it */
@@ -226,10 +245,6 @@ static netwib_err sniff_tcp_hashitem_add_packet(sniff_tcp_hashitem *psthi,
                                       preadpkt, &pitem));
   netwib_er(netwib_ring_add_last(psthi->pring, pitem));
 
-  /* item updated */
-  netwib_er(netwib_time_init_now(&t));
-  psthi->lastupdate = t.sec;
-
   return(NETWIB_ERR_OK);
 }
 
@@ -240,21 +255,22 @@ static netwib_err sniff_tcp_hashitem_add_packet(sniff_tcp_hashitem *psthi,
 typedef struct {
   netwib_hash *phash;
   netwib_buf readpkt;
-  netwib_uint32 countnew;
-  sniff_tcp_hashitem *plaststhi;
+  netwib_uint32 countnewitems; /* to purge after several new items added */
+  netwib_uint32 countpkt; /* to purge after several packet seen */
+  sniff_tcp_hashitem *plaststhi; /* pointer to last hash item. It will be
+                                    used because after giving a fragment to
+                                    user, other out of order packet, previously
+                                    received, may become ordered. There are
+                                    the firsts to give back to user. */
 } netwib_priv_io_sniff_tcp;
 
-/*-------------------------------------------------------------*/
-#define SNIFF_TCP_EXPIRE 30
-#define SNIFF_TCP_CLEAN  20
-
 /*-------------------------------------------------------------*/
 static netwib_err sniff_tcp_read(netwib_priv_io_sniff_tcp *pios,
                                  netwib_device_dlttype dlt,
                                  netwib_constbuf *preadpkt,
                                  netwib_buf *pgivepkt)
 {
-  netwib_byte array[SNIFF_TCP_HASHITEM_KEY_LEN];
+  netwib_byte array[SNIFF_TCP_HASHITEM_KEY_MAXLEN];
   netwib_iphdr iphdr;
   netwib_tcphdr tcpheader;
   netwib_buf key, tcpdata;
@@ -274,14 +290,16 @@ static netwib_err sniff_tcp_read(netwib_priv_io_sniff_tcp *pios,
   }
 
   /* clean hash */
-  if (pios->countnew > SNIFF_TCP_CLEAN) {
+  if (pios->countnewitems > SNIFF_TCPREORD_NEWITEMS_CLEAN ||
+      pios->countpkt > SNIFF_TCPREORD_PKT_CLEAN) {
     netwib_time t;
     netwib_er(netwib_time_init_now(&t));
-    t.sec -= SNIFF_TCP_EXPIRE;
     netwib_er(netwib_hash_del_criteria(pios->phash, &sniff_tcp_hashitem_clean,
                                        &t.sec, NETWIB_TRUE));
-    pios->countnew = 0;
+    pios->countnewitems = 0;
+    pios->countpkt = 0;
   }
+  pios->countpkt++;
 
   /* compute hash key */
   netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &key));
@@ -316,7 +334,7 @@ static netwib_err sniff_tcp_read(netwib_priv_io_sniff_tcp *pios,
     netwib_er(sniff_tcp_hashitem_update(psthi, &tcpheader, &tcpdata));
     /* add it in the hash */
     netwib_er(netwib_hash_add(pios->phash, &key, pitem, NETWIB_TRUE));
-    pios->countnew++;
+    pios->countnewitems++;
     /* give this packet to user */
     netwib_er(netwib_buf_append_buf(preadpkt, pgivepkt));
     return(NETWIB_ERR_OK);
@@ -342,9 +360,8 @@ static netwib_err sniff_tcp_read_pending2(netwib_constptr pitem,
     return(NETWIB_ERR_OK);
   }
 
-  /* to force erase of packets no more synchronized */
-  netwib_er(sniff_tcp_checksynchro(pstri->seqnum, *pseqnum,
-                                   &issynchro));
+  /* trick to force erase of packets no more synchronized */
+  netwib_er(sniff_tcp_checksynchro(pstri->seqnum, *pseqnum, &issynchro));
   if (issynchro) {
     *pbool = NETWIB_FALSE;
   } else {
@@ -387,7 +404,7 @@ static netwib_err sniff_tcp_read_pending(netwib_priv_io_sniff_tcp *pios,
                                            NETWIB_TRUE));
       return(NETWIB_ERR_OK);
     }
-    /* this packet was not synchronized */
+    /* trick (in sniff_tcp_read_pending2): this packet was not synchronized */
     netwib_er(netwib_ring_index_this_del(pios->plaststhi->pringindex,
                                          NETWIB_TRUE));
   }
@@ -411,9 +428,10 @@ static netwib_err netwib_priv_io_sniff_tcp_init(netwib_bool *preadinitialized,
   netwib_er(netwib_buf_init_mallocdefault(&ptr->readpkt));
 
   /* used to clean hash */
-  ptr->countnew = 0;
+  ptr->countnewitems = 0;
+  ptr->countpkt = 0;
 
-  /* used for the wait */
+  /* used for the wait, and to give back packets related to one session */
   ptr->plaststhi = NULL;
 
   /* set io values */
@@ -475,9 +493,9 @@ static netwib_err netwib_priv_io_sniff_tcp_wait(netwib_io *pio,
     return(NETWIB_ERR_OK);
   }
 
+  way = way; /* for compiler warning */
+  pabstime = pabstime; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  way = way;
-  pabstime = pabstime;
 }
 
 /*-------------------------------------------------------------*/
