@@ -70,8 +70,8 @@ static netwib_err netwib_priv_confclean_devices_dup(netwib_constptr piteminf,
 
   /* if we are here, they are equal, so the second will be removed */
   *pcmp = NETWIB_CMP_EQ;
+  pinfos = pinfos; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pinfos = pinfos;
 }
 
 /*-------------------------------------------------------------*/
@@ -146,8 +146,8 @@ static netwib_err netwib_priv_confclean_ip_dup(netwib_constptr piteminf,
   }
 
   *pcmp = cmp;
+  pinfos = pinfos; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pinfos = pinfos;
 }
 
 /*-------------------------------------------------------------*/
@@ -478,8 +478,8 @@ static netwib_err netwib_priv_confclean_arpcache_dup(netwib_constptr piteminf,
     *pcmp = NETWIB_CMP_LT;
   }
 
+  pinfos = pinfos; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pinfos = pinfos;
 }
 
 /*-------------------------------------------------------------*/
@@ -545,8 +545,8 @@ static netwib_err netwib_priv_confclean_routes_dup(netwib_constptr piteminf,
 
   /* if we are here, they are equal, so the second will be removed */
   *pcmp = NETWIB_CMP_EQ;
+  pinfos = pinfos; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pinfos = pinfos;
 }
 
 /*-------------------------------------------------------------*/
