@@ -388,7 +388,7 @@ netwib_err netwib_priv_ip_init_hn6(netwib_conststring hn,
     if (reti == 0) {
       pcur = pres;
       while(pcur != NULL) {
-        ret = netwib_priv_sa_ip_init_sa((netwib_priv_sockaddr *)pcur->ai_addr,
+        ret = netwib_priv_sa_ip_init_sa((netwib_priv_sockaddr_unalign *)pcur->ai_addr,
                                         pip);
         if (ret == NETWIB_ERR_OK) {
           freeaddrinfo(pres);
@@ -612,7 +612,7 @@ netwib_err netwib_priv_ip_buf_append_hn(netwib_constip *pip,
 
 #if NETWIBDEF_HAVEFUNC_GETNAMEINFO == 1
   {
-    netwib_priv_sockaddr sa;
+    netwib_priv_sockaddr_align sa;
     netwib_uint32 salen;
     char *host;
     int reti;
@@ -1054,7 +1054,7 @@ netwib_err netwib_priv_ip_maskprefix_init_ipnet(netwib_constip *pip,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_priv_ip_maskprefix_init_sali(const netwib_priv_sockaddr *psa,
+netwib_err netwib_priv_ip_maskprefix_init_sali(const netwib_priv_sockaddr_unalign *psa,
                                                netwib_uint32 supposedsalen,
                                                netwib_iptype supposediptype,
                                                netwib_ip *pmask,
