@@ -28,19 +28,9 @@
 
 #include <netwib/inc/maininc.h>
 
-/*-------------------------------------------------------------*/
-typedef enum {
-  NETWIB_PRIV_IO_SOCKTYPE_UDP_CLI = 1,
-  NETWIB_PRIV_IO_SOCKTYPE_TCP_CLI,
-  NETWIB_PRIV_IO_SOCKTYPE_UDP_SER,
-  NETWIB_PRIV_IO_SOCKTYPE_TCP_SER,
-  NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER,
-  NETWIB_PRIV_IO_SOCKTYPE_TCP_MULSER
-} netwib_priv_io_socktype;
-
 /*-------------------------------------------------------------*/
 typedef struct {
-  netwib_priv_io_socktype socktype;
+  netwib_io_socktype socktype;
   int fd;
   netwib_ip localip;
   netwib_ip remoteip;
@@ -53,7 +43,7 @@ typedef struct {
 } netwib_priv_io_sock;
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_io_sock_init(netwib_priv_io_socktype socktype,
+static netwib_err netwib_priv_io_sock_init(netwib_io_socktype socktype,
                                            netwib_constip *plocalip,
                                            netwib_constip *premoteip,
                                            netwib_iptype iptype,
@@ -69,9 +59,8 @@ static netwib_err netwib_priv_io_sock_init(netwib_priv_io_socktype socktype,
   netwib_data ip4opts;
   netwib_uint32 ip4optssize;
   netwib_uint32 salen;
-  netwib_bool ip6supported;
   netwib_err ret;
-  netwib_priv_sockaddr sa;
+  netwib_priv_sockaddr_align sa;
   int reti, sockettype=0, socketproto=0, socketdomain=0, one;
 
   ptr->socktype = socktype;
@@ -104,15 +93,15 @@ static netwib_err netwib_priv_io_sock_init(netwib_priv_io_socktype socktype,
       break;
   }
   switch(ptr->socktype) {
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_CLI :
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_SER :
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER :
+    case NETWIB_IO_SOCKTYPE_UDP_CLI :
+    case NETWIB_IO_SOCKTYPE_UDP_SER :
+    case NETWIB_IO_SOCKTYPE_UDP_MULSER :
       sockettype = SOCK_DGRAM;
       socketproto = IPPROTO_UDP;
       break;
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_CLI :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_SER :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_MULSER :
+    case NETWIB_IO_SOCKTYPE_TCP_CLI :
+    case NETWIB_IO_SOCKTYPE_TCP_SER :
+    case NETWIB_IO_SOCKTYPE_TCP_MULSER :
       sockettype = SOCK_STREAM;
       socketproto = IPPROTO_TCP;
       break;
@@ -152,8 +141,8 @@ static netwib_err netwib_priv_io_sock_init(netwib_priv_io_socktype socktype,
 
   /* connect or listen/accept */
   switch(ptr->socktype) {
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_CLI :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_CLI :
+    case NETWIB_IO_SOCKTYPE_UDP_CLI :
+    case NETWIB_IO_SOCKTYPE_TCP_CLI :
       if (premoteip != NULL || remoteport != 0) {
         netwib_eg(netwib_priv_sa_sal_init_iptport(premoteip, iptype,
                                                   remoteport, &sa, &salen));
@@ -161,7 +150,7 @@ static netwib_err netwib_priv_io_sock_init(netwib_priv_io_socktype socktype,
         netwib_ig(reti, NETWIB_ERR_FUCONNECT);
       }
       break;
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_SER :
+    case NETWIB_IO_SOCKTYPE_TCP_SER :
       reti = listen(ptr->fd, 1);
       netwib_ig(reti, NETWIB_ERR_FULISTEN);
       if (pip4opts != NULL) {
@@ -172,9 +161,9 @@ static netwib_err netwib_priv_io_sock_init(netwib_priv_io_socktype socktype,
         netwib_ig(reti, NETWIB_ERR_FUSETSOCKOPT);
       }
       break;
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_SER :
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_MULSER :
+    case NETWIB_IO_SOCKTYPE_UDP_SER :
+    case NETWIB_IO_SOCKTYPE_UDP_MULSER :
+    case NETWIB_IO_SOCKTYPE_TCP_MULSER :
       /* nothing to do */
       break;
   }
@@ -191,7 +180,6 @@ static netwib_err netwib_priv_io_sock_init(netwib_priv_io_socktype socktype,
   netwib_er(netwib_buf_close(&ptr->ip4opts));
   netwib_er(netwib_buf_close(&ptr->ip6exts));
   return(ret);
-  ip6supported = ip6supported;
 }
 
 /*-------------------------------------------------------------*/
@@ -208,7 +196,7 @@ static netwib_err netwib_priv_io_sock_init_tms(int fd,
   int reti;
 
   /* init resources */
-  ptr->socktype = NETWIB_PRIV_IO_SOCKTYPE_TCP_MULSER;
+  ptr->socktype = NETWIB_IO_SOCKTYPE_TCP_MULSER;
   ptr->fd = fd;
   ptr->clientconnected = NETWIB_FALSE;
 
@@ -273,12 +261,12 @@ static netwib_err netwib_priv_io_sock_read(netwib_io *pio,
                                            netwib_buf *pbuf)
 {
   netwib_priv_io_sock *ptr = (netwib_priv_io_sock *)pio->pcommon;
-  netwib_priv_sockaddr sa;
+  netwib_priv_sockaddr_align sa;
   netwib_uint32 salen;
   int reti;
 
   switch(ptr->socktype) {
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_SER :
+    case NETWIB_IO_SOCKTYPE_TCP_SER :
       if (! ptr->clientconnected) {
         netwib_er(netwib_priv_io_sock_tcpaccept(ptr));
         /* the client connection event might not indicate data. If there
@@ -286,12 +274,12 @@ static netwib_err netwib_priv_io_sock_read(netwib_io *pio,
         return(NETWIB_ERR_DATANOTAVAIL);
       }
       /* no break */
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_CLI :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_CLI :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_MULSER :
+    case NETWIB_IO_SOCKTYPE_UDP_CLI :
+    case NETWIB_IO_SOCKTYPE_TCP_CLI :
+    case NETWIB_IO_SOCKTYPE_TCP_MULSER :
       netwib_er(netwib_priv_sa_recv(ptr->fd, pbuf));
       break;
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_SER :
+    case NETWIB_IO_SOCKTYPE_UDP_SER :
       netwib_er(netwib_priv_sa_recvfrom(ptr->fd, pbuf, &sa, &salen));
       if (!ptr->clientconnected) {
         /* connect back on client to be able to write */
@@ -300,9 +288,9 @@ static netwib_err netwib_priv_io_sock_read(netwib_io *pio,
         ptr->clientconnected = NETWIB_TRUE;
       }
       break;
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER :
+    case NETWIB_IO_SOCKTYPE_UDP_MULSER :
       netwib_er(netwib_priv_sa_recvfrom(ptr->fd, pbuf, &sa, &salen));
-      netwib_er(netwib_priv_sa_ipport_init_sal(&sa, salen, &ptr->remoteip,
+      netwib_er(netwib_priv_sa_ipport_init_sal((netwib_priv_sockaddr_unalign*)&sa, salen, &ptr->remoteip,
                                                &ptr->remoteport));
       ptr->clientconnected = NETWIB_TRUE;
       break;
@@ -316,17 +304,17 @@ static netwib_err netwib_priv_io_sock_write(netwib_io *pio,
                                             netwib_constbuf *pbuf)
 {
   netwib_priv_io_sock *ptr = (netwib_priv_io_sock *)pio->pcommon;
-  netwib_priv_sockaddr sa;
+  netwib_priv_sockaddr_align sa;
   netwib_uint32 salen;
 
   switch(ptr->socktype) {
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_SER :
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER :
+    case NETWIB_IO_SOCKTYPE_UDP_SER :
+    case NETWIB_IO_SOCKTYPE_UDP_MULSER :
       if (!ptr->clientconnected) {
         return(NETWIB_ERR_LOUDPSERREADBEFWRITE);
       }
       break;
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_SER :
+    case NETWIB_IO_SOCKTYPE_TCP_SER :
       if (! ptr->clientconnected) {
         netwib_er(netwib_priv_io_sock_tcpaccept(ptr));
       }
@@ -336,17 +324,17 @@ static netwib_err netwib_priv_io_sock_write(netwib_io *pio,
   }
 
   switch(ptr->socktype) {
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_CLI :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_CLI :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_SER :
-    case NETWIB_PRIV_IO_SOCKTYPE_TCP_MULSER :
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_SER :
+    case NETWIB_IO_SOCKTYPE_UDP_CLI :
+    case NETWIB_IO_SOCKTYPE_TCP_CLI :
+    case NETWIB_IO_SOCKTYPE_TCP_SER :
+    case NETWIB_IO_SOCKTYPE_TCP_MULSER :
+    case NETWIB_IO_SOCKTYPE_UDP_SER :
       netwib_er(netwib_priv_sa_send(ptr->fd, pbuf));
       break;
-    case NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER :
+    case NETWIB_IO_SOCKTYPE_UDP_MULSER :
       netwib_er(netwib_priv_sa_sal_init_ipport(&ptr->remoteip, ptr->remoteport,
                                                &sa, &salen));
-      netwib_er(netwib_priv_sa_sendto(ptr->fd, pbuf, &sa, salen));
+      netwib_er(netwib_priv_sa_sendto(ptr->fd, pbuf, (netwib_priv_sockaddr_unalign*)&sa, salen));
       break;
   }
 
@@ -363,7 +351,7 @@ static netwib_err netwib_priv_io_sock_wait(netwib_io *pio,
   netwib_bool event;
 
   netwib_er(netwib_priv_fd_wait(ptr->fd, way, pabstime, &event));
-  if (event && ptr->socktype == NETWIB_PRIV_IO_SOCKTYPE_TCP_SER) {
+  if (event && ptr->socktype == NETWIB_IO_SOCKTYPE_TCP_SER) {
     if (! ptr->clientconnected) {
       netwib_er(netwib_priv_io_sock_tcpaccept(ptr));
     }
@@ -417,13 +405,15 @@ static netwib_err netwib_priv_io_sock_ctl_set(netwib_io *pio,
       netwib_ir(reti, NETWIB_ERR_FUSETSOCKOPT);
       return(NETWIB_ERR_OK);
       break;
+    case NETWIB_IO_CTLTYPE_SOCK_SOCKTYPE:
+      return(NETWIB_ERR_PAINVALIDTYPE);
     default:
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  way = way; /* for compiler warning */
+  ui = ui; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  way = way;
-  ui = ui;
 }
 
 /*-------------------------------------------------------------*/
@@ -434,7 +424,7 @@ static netwib_err netwib_priv_io_sock_ctl_get(netwib_io *pio,
                                               netwib_uint32 *pui)
 {
   netwib_priv_io_sock *ptr = (netwib_priv_io_sock *)pio->pcommon;
-  netwib_priv_sockaddr sa;
+  netwib_priv_sockaddr_align sa;
   netwib_uint32 salen;
   int reti;
 
@@ -453,33 +443,34 @@ static netwib_err netwib_priv_io_sock_ctl_get(netwib_io *pio,
       return(NETWIB_ERR_OK);
       break;
     case NETWIB_IO_CTLTYPE_SOCK_LOCAL:
-      salen = sizeof(netwib_priv_sockaddr);
+      salen = sizeof(sa);
       reti = netwib_c_getsockname(ptr->fd, (struct sockaddr *)&sa, &salen);
       netwib_ir(reti, NETWIB_ERR_FUGETSOCKNAME);
-      netwib_er(netwib_priv_sa_ipport_init_sal(&sa, salen, &ptr->localip,
-                                               &ptr->localport));
+      netwib_er(netwib_priv_sa_ipport_init_sal((netwib_priv_sockaddr_unalign*)&sa, salen, &ptr->localip, &ptr->localport));
       if (p != NULL) *(netwib_ip*)p = ptr->localip;
       if (pui != NULL) *pui = ptr->localport;
       return(NETWIB_ERR_OK);
     case NETWIB_IO_CTLTYPE_SOCK_REMOTE:
-      if (ptr->socktype != NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER) {
-        salen = sizeof(netwib_priv_sockaddr);
+      if (ptr->socktype != NETWIB_IO_SOCKTYPE_UDP_MULSER) {
+        salen = sizeof(sa);
         reti = netwib_c_getpeername(ptr->fd, (struct sockaddr *)&sa, &salen);
         netwib_ir(reti, NETWIB_ERR_FUGETPEERNAME);
-        netwib_er(netwib_priv_sa_ipport_init_sal(&sa, salen, &ptr->remoteip,
-                                                 &ptr->remoteport));
+        netwib_er(netwib_priv_sa_ipport_init_sal((netwib_priv_sockaddr_unalign*)&sa, salen, &ptr->remoteip, &ptr->remoteport));
       }
       if (p != NULL) *(netwib_ip*)p = ptr->remoteip;
       if (pui != NULL) *pui = ptr->remoteport;
       return(NETWIB_ERR_OK);
     case NETWIB_IO_CTLTYPE_SOCK_MULTICASTTTL:
       return(NETWIB_ERR_PAINVALIDTYPE);
+    case NETWIB_IO_CTLTYPE_SOCK_SOCKTYPE:
+      if (p != NULL) *(netwib_io_socktype*)p = ptr->socktype;
+      return(NETWIB_ERR_OK);
     default:
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  way = way; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  way = way;
 }
 
 /*-------------------------------------------------------------*/
@@ -507,7 +498,7 @@ netwib_err netwib_io_init_sock_udp_cli_full(netwib_constip *plocalip,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_sock), &pcommon));
-  ret = netwib_priv_io_sock_init(NETWIB_PRIV_IO_SOCKTYPE_UDP_CLI,
+  ret = netwib_priv_io_sock_init(NETWIB_IO_SOCKTYPE_UDP_CLI,
                                  plocalip, premoteip, (netwib_iptype)0,
                                  localport, remoteport,
                                  pip4opts, ip6extsproto, pip6exts,
@@ -547,7 +538,7 @@ netwib_err netwib_io_init_sock_tcp_cli_full(netwib_constip *plocalip,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_sock), &pcommon));
-  ret = netwib_priv_io_sock_init(NETWIB_PRIV_IO_SOCKTYPE_TCP_CLI,
+  ret = netwib_priv_io_sock_init(NETWIB_IO_SOCKTYPE_TCP_CLI,
                                  plocalip, premoteip, (netwib_iptype)0,
                                  localport, remoteport,
                                  pip4opts, ip6extsproto, pip6exts,
@@ -585,7 +576,7 @@ netwib_err netwib_io_init_sock_udp_ser_full(netwib_constip *plocalip,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_sock), &pcommon));
-  ret = netwib_priv_io_sock_init(NETWIB_PRIV_IO_SOCKTYPE_UDP_SER,
+  ret = netwib_priv_io_sock_init(NETWIB_IO_SOCKTYPE_UDP_SER,
                                  plocalip, NULL, (netwib_iptype)0,
                                  localport, 0,
                                  pip4opts, ip6extsproto, pip6exts,
@@ -620,7 +611,7 @@ netwib_err netwib_io_init_sock_udp_ser_easy(netwib_iptype iptype,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_sock), &pcommon));
-  ret = netwib_priv_io_sock_init(NETWIB_PRIV_IO_SOCKTYPE_UDP_SER,
+  ret = netwib_priv_io_sock_init(NETWIB_IO_SOCKTYPE_UDP_SER,
                                  NULL, NULL, iptype,
                                  localport, 0,
                                  NULL, NETWIB_IPPROTO_NONE, NULL,
@@ -658,7 +649,7 @@ netwib_err netwib_io_init_sock_tcp_ser_full(netwib_constip *plocalip,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_sock), &pcommon));
-  ret = netwib_priv_io_sock_init(NETWIB_PRIV_IO_SOCKTYPE_TCP_SER,
+  ret = netwib_priv_io_sock_init(NETWIB_IO_SOCKTYPE_TCP_SER,
                                  plocalip, NULL, (netwib_iptype)0,
                                  localport, 0,
                                  pip4opts, ip6extsproto, pip6exts,
@@ -693,7 +684,7 @@ netwib_err netwib_io_init_sock_tcp_ser_easy(netwib_iptype iptype,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_sock), &pcommon));
-  ret = netwib_priv_io_sock_init(NETWIB_PRIV_IO_SOCKTYPE_TCP_SER,
+  ret = netwib_priv_io_sock_init(NETWIB_IO_SOCKTYPE_TCP_SER,
                                  NULL, NULL, iptype,
                                  localport, 0,
                                  NULL, NETWIB_IPPROTO_NONE, NULL,
@@ -731,7 +722,7 @@ netwib_err netwib_io_init_sock_udp_mulser_full(netwib_constip *plocalip,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_sock), &pcommon));
-  ret = netwib_priv_io_sock_init(NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER,
+  ret = netwib_priv_io_sock_init(NETWIB_IO_SOCKTYPE_UDP_MULSER,
                                  plocalip, NULL, (netwib_iptype)0,
                                  localport, 0,
                                  pip4opts, ip6extsproto, pip6exts,
@@ -766,7 +757,7 @@ netwib_err netwib_io_init_sock_udp_mulser_easy(netwib_iptype iptype,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_sock), &pcommon));
-  ret = netwib_priv_io_sock_init(NETWIB_PRIV_IO_SOCKTYPE_UDP_MULSER,
+  ret = netwib_priv_io_sock_init(NETWIB_IO_SOCKTYPE_UDP_MULSER,
                                  NULL, NULL, iptype,
                                  localport, 0,
                                  NULL, NETWIB_IPPROTO_NONE, NULL,
@@ -844,8 +835,8 @@ static netwib_err netwib_sock_tcp_mulser_cli(netwib_ptr infosin,
   netwib_er(netwib_io_close(&pio));
 
   netwib_er(netwib_ptr_free((netwib_ptr*)&ptmi));
+  pinfosout = pinfosout; /* for compiler warning */
   return(ret);
-  pinfosout = pinfosout;
 }
 
 /*-------------------------------------------------------------*/
@@ -861,8 +852,8 @@ static netwib_err netwib_sock_tcp_mulser2(netwib_constip *plocalip,
   netwib_data ip4opts;
   netwib_uint32 ip4optssize;
   netwib_uint32 salen, threadid;
-  netwib_bool ip6supported, ringset, event;
-  netwib_priv_sockaddr sa;
+  netwib_bool ringset, event;
+  netwib_priv_sockaddr_align sa;
   netwib_ring *pring;
   netwib_priv_sock_tcp_mulser_info *ptmi;
   netwib_thread *pthread;
@@ -962,7 +953,6 @@ static netwib_err netwib_sock_tcp_mulser2(netwib_constip *plocalip,
   }
   netwib_c_closesocket(fd);
   return(ret);
-  ip6supported = ip6supported;
 }
 
 /*-------------------------------------------------------------*/
