@@ -30,18 +30,18 @@
 
 /*-------------------------------------------------------------*/
 #if defined NETWIBDEF_SYSNAME_Unix
-static netwib_err netwib_priv_dirname_secure(netwib_conststring dirname,
+static netwib_err netwib_priv_dirname_secure(netwib_conststring dirnamestr,
                                              netwib_bool *pyes)
 {
   struct stat st;
   netwib_bool yes;
   int reti;
 
-  reti = lstat(dirname, &st);
+  reti = lstat(dirnamestr, &st);
   if (reti == -1) {
     if (errno == ENOENT || errno == ENOTDIR) {
       netwib_er(netwib_priv_errmsg_text("file not found: "));
-      netwib_er(netwib_priv_errmsg_append_text(dirname));
+      netwib_er(netwib_priv_errmsg_append_text(dirnamestr));
       return(NETWIB_ERR_NOTFOUND);
     }
     return(NETWIB_ERR_FULSTAT);
@@ -129,8 +129,8 @@ netwib_err netwib_dirname_secure(netwib_constbuf *pdirname,
 #elif defined NETWIBDEF_SYSNAME_Windows
 {
   if (pyes != NULL) *pyes = NETWIB_TRUE;
+  pdirname = pdirname; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pdirname = pdirname;
 }
 #else
  #error "Unknown value for NETWIBDEF_SYSNAME"
@@ -219,13 +219,13 @@ netwib_err netwib_dirname_create(netwib_constbuf *pdirname)
 /*-------------------------------------------------------------*/
 netwib_err netwib_dirname_remove(netwib_constbuf *pdirname)
 {
-  netwib_string dirname;
+  netwib_string dirnamestr;
   int reti;
 
-  netwib__buf_ref_string(pdirname, dirname, bufstorage,
+  netwib__buf_ref_string(pdirname, dirnamestr, bufstorage,
                          netwib_dirname_remove(&bufstorage));
 
-  reti = netwib_c_rmdir(dirname);
+  reti = netwib_c_rmdir(dirnamestr);
   if (reti == -1) {
     netwib_er(netwib_priv_errmsg_text("cannot remove this dir: "));
     netwib_er(netwib_priv_errmsg_append_buf(pdirname));
