@@ -767,8 +767,8 @@ static netwib_err netwib_priv_io_ctl_set_current(netwib_io *pio,
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  p = p; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  p = p;
 }
 
 /*-------------------------------------------------------------*/
@@ -940,8 +940,8 @@ static netwib_err netwib_priv_io_ctl_get_current(netwib_io *pio,
 
   if (pui != NULL) *pui = ui;
 
+  p = p; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  p = p;
 }
 
 /*-------------------------------------------------------------*/
@@ -1111,8 +1111,8 @@ static netwib_err netwib_priv_io_close_cmp(netwib_constptr piteminf,
     if (pcmp != NULL) *pcmp = NETWIB_CMP_LT;
   }
 
+  pinfos = pinfos; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pinfos = pinfos;
 }
 
 /*-------------------------------------------------------------*/
