@@ -453,6 +453,10 @@ netwib_err netwib_path_decode(netwib_constbuf *ppathname,
   netwib_uint32 datasize;
   netwib_err ret;
 
+  if (netwib__buf_ref_data_sizenull(ppathname) == 0) {
+    return(NETWIB_ERR_PAPATHNOTCANON);
+  }
+
   switch(type) {
   case NETWIB_PATH_DECODETYPE_BEGIN :
     netwib_er(netwib_priv_path_info(ppathname, NULL, pout, NULL));
@@ -506,8 +510,8 @@ netwib_err netwib_path_decode(netwib_constbuf *ppathname,
     netwib_er(ret);
     break;
   case NETWIB_PATH_DECODETYPE_EXTENSION :
-    data = netwib__buf_ref_data_ptr(ppathname);
     datasize = netwib__buf_ref_data_size(ppathname);
+    data = netwib__buf_ref_data_ptr(ppathname);
     data += datasize;
     while (NETWIB_TRUE) {
       if (datasize == 0) { /* no extension */
@@ -928,6 +932,11 @@ netwib_err netwib_path_init(netwib_constbuf *pdirname1,
 {
   netwib_err ret=NETWIB_ERR_OK;
 
+  if (netwib__buf_ref_data_sizenull(pdirname1) == 0 ||
+      netwib__buf_ref_data_sizenull(ppathname2) == 0) {
+    return(NETWIB_ERR_PAPATHNOTCANON);
+  }
+
   switch(type) {
     case NETWIB_PATH_INITTYPE_CONCAT :
       ret = netwib_priv_path_init_concat(pdirname1, ppathname2, pout);
