@@ -434,8 +434,8 @@ static netwib_err netwib_priv_io_data_ctl_set(netwib_io *pio,
     return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  p = p; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  p = p;
 }
 
 /*-------------------------------------------------------------*/
@@ -469,8 +469,8 @@ static netwib_err netwib_priv_io_data_ctl_get(netwib_io *pio,
     return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  p = p; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  p = p;
 }
 
 /*-------------------------------------------------------------*/
