@@ -172,8 +172,8 @@ static netwib_err netwib_priv_io_mem_wait(netwib_io *pio,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
+  pabstime = pabstime; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pabstime = pabstime;
 }
 
 /*-------------------------------------------------------------*/
@@ -243,8 +243,8 @@ static netwib_err netwib_priv_io_mem_wait_lock(netwib_io *pio,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
+  pabstime = pabstime; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pabstime = pabstime;
 }
 
 /*-------------------------------------------------------------*/
@@ -297,9 +297,9 @@ static netwib_err netwib_priv_io_mem_ctl_set(netwib_io *pio,
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  p = p; /* for compiler warning */
+  ui = ui; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  p = p;
-  ui = ui;
 }
 
 /*-------------------------------------------------------------*/
@@ -355,10 +355,10 @@ static netwib_err netwib_priv_io_mem_ctl_get(netwib_io *pio,
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  p = p; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  way = way;
-  p = p;
 }
 
 /*-------------------------------------------------------------*/
