@@ -187,8 +187,8 @@ static netwib_err netwib_priv_io_tlv_wait(netwib_io *pio,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
+  pabstime = pabstime; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pabstime = pabstime;
 }
 
 /*-------------------------------------------------------------*/
@@ -258,8 +258,8 @@ static netwib_err netwib_priv_io_tlv_wait_lock(netwib_io *pio,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
+  pabstime = pabstime; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pabstime = pabstime;
 }
 
 /*-------------------------------------------------------------*/
@@ -320,9 +320,9 @@ static netwib_err netwib_priv_io_tlv_ctl_set(netwib_io *pio,
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  p = p; /* for compiler warning */
+  ui = ui; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  p = p;
-  ui = ui;
 }
 
 /*-------------------------------------------------------------*/
@@ -377,10 +377,10 @@ static netwib_err netwib_priv_io_tlv_ctl_get(netwib_io *pio,
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  p = p; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  way = way;
-  p = p;
 }
 
 /*-------------------------------------------------------------*/
