@@ -347,6 +347,10 @@ static netwib_err netwib_priv_io_record_init(netwib_constbuf *precordname,
       *preadinitialized = NETWIB_FALSE;
       *pwriteinitialized = NETWIB_TRUE;
       break;
+    case NETWIB_FILE_INITTYPE_RDWR :
+      /* continue */
+    default :
+      return(NETWIB_ERR_LONOTSUPPORTED);
   }
 
   /* we can only set pcap info now (after allocating) */
@@ -609,11 +613,11 @@ static netwib_err netwib_priv_io_record_wait(netwib_io *pio,
   /* always return true because it's a file */
   *pevent = NETWIB_TRUE;
 
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  pabstime = pabstime; /* for compiler warning */
+  pevent = pevent; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pio = pio;
-  way = way;
-  pabstime = pabstime;
-  pevent = pevent;
 }
 
 /*-------------------------------------------------------------*/
@@ -637,10 +641,10 @@ static netwib_err netwib_priv_io_record_ctl_set(netwib_io *pio,
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  way = way; /* for compiler warning */
+  p = p; /* for compiler warning */
+  ui = ui; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  way = way;
-  p = p;
-  ui = ui;
 }
 
 /*-------------------------------------------------------------*/
@@ -661,10 +665,10 @@ static netwib_err netwib_priv_io_record_ctl_get(netwib_io *pio,
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  p = p; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  way = way;
-  p = p;
 }
 
 /*-------------------------------------------------------------*/
