@@ -707,7 +707,7 @@ static netwib_err netwox_scan_reply_check_target(netwox_scan *pscan,
 static netwib_err netwox_scan_reply_check(netwox_scan *pscan,
                                           netwox_scan_reply_info *pri)
 {
-  netwib_scan_target_display disp;
+  netwib_scan_target_display disp=0;
   netwib_bool match;
   netwib_eth eth;
   netwib_uint32 i;
