@@ -37,7 +37,7 @@ netwib_conststring t000094_description[] = {
   "have the full path. For example '/bin/sh -c ls', and not just 'ls'.",
   "Parameter --dst-file defines the file containing the result of",
   "command.",
-  NETWOX_DESC_backdoor_passcyp,
+  NETWOX_DESC_remadm_passcyp,
   NETWOX_DESC_client,
   NETWOX_DESC_toolpriv_none,
   NULL
@@ -53,11 +53,11 @@ netwox_toolarg t000094_args[] = {
   NETWOX_TOOLARG_END
 };
 netwox_tooltreenodetype t000094_nodes[] = {
-  NETWOX_TOOLTREENODETYPE_BACKDOOR,
+  NETWOX_TOOLTREENODETYPE_REMADM,
   NETWOX_TOOLTREENODETYPE_END
 };
 netwox_tool_info t000094_info = {
-  "TCP backdoor client (exec)",
+  "TCP remote administration client (exec)",
   t000094_description,
   NULL,
   t000094_args,
@@ -69,7 +69,7 @@ netwib_err t000094_core(int argc, char *argv[])
 {
   netwox_arg *parg;
   netwox_sockinfo sockinfo;
-  netwox_bkdortcp_cli bkdortcp;
+  netwox_remadmtcp_cli remadmtcp;
   netwib_io *psockio, *plocalio;
   netwib_buf pwd, cmd, localfile;
   netwib_bool cypher, isset;
@@ -94,24 +94,24 @@ netwib_err t000094_core(int argc, char *argv[])
 
   /* initialize structure */
   netwib_er(netwox_sock_init(&sockinfo, &psockio));
-  netwib_er(netwox_bkdortcp_cli_init(psockio, timeoutsec, &bkdortcp));
+  netwib_er(netwox_remadmtcp_cli_init(psockio, timeoutsec, &remadmtcp));
 
   /* cypher (data will not be in clear text) */
   if (cypher) {
-    netwib_er(netwox_bkdortcp_cli_cypher(&bkdortcp, &pwd));
+    netwib_er(netwox_remadmtcp_cli_cypher(&remadmtcp, &pwd));
   }
 
   /* authenticate */
-  netwib_er(netwox_bkdortcp_cli_auth(&bkdortcp, &pwd));
+  netwib_er(netwox_remadmtcp_cli_auth(&remadmtcp, &pwd));
 
   /* run */
-  netwib_er(netwox_bkdortcp_cli_exec(&bkdortcp, &cmd, plocalio, NULL));
+  netwib_er(netwox_remadmtcp_cli_exec(&remadmtcp, &cmd, plocalio, NULL));
 
   /* quit */
-  netwib_er(netwox_bkdortcp_cli_quit(&bkdortcp));
+  netwib_er(netwox_remadmtcp_cli_quit(&remadmtcp));
 
   /* close */
-  netwib_er(netwox_bkdortcp_cli_close(&bkdortcp));
+  netwib_er(netwox_remadmtcp_cli_close(&remadmtcp));
   netwib_er(netwox_sockinfo_close(&sockinfo));
   netwib_er(netwib_io_close(&plocalio));
   netwib_er(netwib_io_close(&psockio));
