@@ -122,8 +122,10 @@ static netwib_err netwib_ip_init_buf_test2(netwib_conststring ips,
 
   return(NETWIB_ERR_OK);
 }
-static netwib_err netwib_ip_init_buf_test3(netwib_conststring ips,
-                                           netwib_conststring wantedips)
+netwib_err netwib_ip_init_buf_test3(netwib_conststring ips,
+                                    netwib_conststring wantedips);
+netwib_err netwib_ip_init_buf_test3(netwib_conststring ips,
+                                    netwib_conststring wantedips)
 {
   netwib_buf buf;
   netwib_ip wantedip;
@@ -251,12 +253,13 @@ static netwib_err netwib_ip_init_buf_test(void)
 #endif
 
   return(NETWIB_ERR_OK);
-  netwib_er(netwib_ip_init_buf_test3("", ""));
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_ip_init_eth_test2(netwib_conststring eths,
-                                           netwib_conststring wantedips)
+netwib_err netwib_ip_init_eth_test2(netwib_conststring eths,
+                                    netwib_conststring wantedips);
+netwib_err netwib_ip_init_eth_test2(netwib_conststring eths,
+                                    netwib_conststring wantedips)
 {
   netwib_buf buf;
   netwib_ip wantedip, ipa;
@@ -351,7 +354,6 @@ static netwib_err netwib_ip_init_eth_test(void)
 #endif
 
   return(NETWIB_ERR_OK);
-  netwib_er(netwib_ip_init_eth_test2("", ""));
 }
 
 /*-------------------------------------------------------------*/
@@ -434,9 +436,12 @@ static netwib_err netwib_buf_append_ip_test2(netwib_constip *pip,
 
   return(NETWIB_ERR_OK);
 }
-static netwib_err netwib_buf_append_ip_test3(netwib_conststring ips,
-                                             netwib_bool canconvert,
-                                             netwib_conststring hn)
+netwib_err netwib_buf_append_ip_test3(netwib_conststring ips,
+                                      netwib_bool canconvert,
+                                      netwib_conststring hn);
+netwib_err netwib_buf_append_ip_test3(netwib_conststring ips,
+                                      netwib_bool canconvert,
+                                      netwib_conststring hn)
 {
   netwib_buf buf;
   netwib_ip ipa;
@@ -571,7 +576,6 @@ static netwib_err netwib_buf_append_ip_test(void)
 #endif
 
   return(NETWIB_ERR_OK);
-  netwib_er(netwib_buf_append_ip_test3("", NETWIB_FALSE, ""));
 }
 
 /*-------------------------------------------------------------*/
