@@ -228,8 +228,10 @@ static netwib_err netwib_ips_add_buf_test2(netwib_conststring text,
   return(ret);
 }
 /*-------------------------------------------------------------*/
-static netwib_err netwib_ips_add_buf_test3(netwib_conststring hn,
-                                           netwib_conststring ipa)
+netwib_err netwib_ips_add_buf_test3(netwib_conststring hn,
+                                    netwib_conststring ipa);
+netwib_err netwib_ips_add_buf_test3(netwib_conststring hn,
+                                    netwib_conststring ipa)
 {
   netwib_buf buf;
   netwib_string pc;
@@ -353,7 +355,6 @@ static netwib_err netwib_ips_add_buf_test(void)
 #endif
 
   return(NETWIB_ERR_OK);
-  netwib_er(netwib_ips_add_buf_test3("", ""));
 }
 
 /*-------------------------------------------------------------*/
