@@ -5,17 +5,17 @@ static netwib_err notdone_read(netwib_io *pio,
                                netwib_buf *pbuf)
 {
   netwib_er(netwib_fmt_display("notdone_read\n"));
+  pio = pio; /* for compiler warning */
+  pbuf = pbuf; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  pbuf = pbuf;
 }
 static netwib_err notdone_write(netwib_io *pio,
                                 netwib_constbuf *pbuf)
 {
   netwib_er(netwib_fmt_display("notdone_write\n"));
+  pio = pio; /* for compiler warning */
+  pbuf = pbuf; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  pbuf = pbuf;
 }
 static netwib_err notdone_wait(netwib_io *pio,
                                netwib_io_waytype way,
@@ -23,19 +23,19 @@ static netwib_err notdone_wait(netwib_io *pio,
                                netwib_bool *pevent)
 {
   netwib_er(netwib_fmt_display("notdone_wait\n"));
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  pabstime = pabstime; /* for compiler warning */
+  pevent = pevent; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  way = way;
-  pabstime = pabstime;
-  pevent = pevent;
 }
 static netwib_err notdone_unread(netwib_io *pio,
                                  netwib_constbuf *pbuf)
 {
   netwib_er(netwib_fmt_display("notdone_unread\n"));
+  pio = pio; /* for compiler warning */
+  pbuf = pbuf; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  pbuf = pbuf;
 }
 static netwib_err notdone_ctl_set(netwib_io *pio,
                                   netwib_io_waytype way,
@@ -44,12 +44,12 @@ static netwib_err notdone_ctl_set(netwib_io *pio,
                                   netwib_uint32 ui)
 {
   netwib_er(netwib_fmt_display("notdone_ctl_set\n"));
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  type = type; /* for compiler warning */
+  p = p; /* for compiler warning */
+  ui = ui; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  way = way;
-  type = type;
-  p = p;
-  ui = ui;
 }
 static netwib_err notdone_ctl_get(netwib_io *pio,
                                   netwib_io_waytype way,
@@ -58,18 +58,18 @@ static netwib_err notdone_ctl_get(netwib_io *pio,
                                   netwib_uint32 *pui)
 {
   netwib_er(netwib_fmt_display("notdone_ctl_get\n"));
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  type = type; /* for compiler warning */
+  p = p; /* for compiler warning */
+  pui = pui; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  way = way;
-  type = type;
-  p = p;
-  pui = pui;
 }
 static netwib_err notdone_close(netwib_io *pio)
 {
   netwib_er(netwib_fmt_display("notdone_close\n"));
+  pio = pio; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pio = pio;
 }
 static netwib_err notdone(netwib_io **ppio)
 {
@@ -185,8 +185,8 @@ static netwib_err usenext_ctl_get(netwib_io *pio,
 static netwib_err usenext_close(netwib_io *pio)
 {
   netwib_er(netwib_fmt_display("usenext_close\n"));
+  pio = pio; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pio = pio;
 }
 static netwib_err usenext(netwib_io **ppio)
 {
@@ -205,8 +205,8 @@ static netwib_err cstmsg_read(netwib_io *pio,
                               netwib_buf *pbuf)
 {
   netwib_er(netwib_buf_append_text("cstmsg text\n", pbuf));
+  pio = pio; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pio = pio;
 }
 static netwib_err cstmsg_wait(netwib_io *pio,
                               netwib_io_waytype way,
@@ -214,18 +214,18 @@ static netwib_err cstmsg_wait(netwib_io *pio,
                               netwib_bool *pevent)
 {
   *pevent = NETWIB_TRUE;
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  pabstime = pabstime; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pio = pio;
-  way = way;
-  pabstime = pabstime;
 }
 static netwib_err cstmsg_unread(netwib_io *pio,
                                 netwib_constbuf *pbuf)
 {
   netwib_er(netwib_fmt_display("cstmsg_unread of : "));
   netwib_er(netwib_buf_display(pbuf, NETWIB_ENCODETYPE_DATA));
+  pio = pio; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pio = pio;
 }
 static netwib_err cstmsg(netwib_io **ppio)
 {
