@@ -543,12 +543,30 @@ netwib_err netwibtest_uint64_content(netwib_uint64 ui,
   netwib_buf buf;
 
   netwib_er(netwib_buf_init_mallocdefault(&buf));
-#if NETWIB_INT64_FAKE == 1
+
+#if 0
+  {
+    netwib_data data;
+    netwib_uint32 datasize;
+    netwib_er(netwib_buf_wantspace(&buf, 80, &data));
+ #if NETWIB_INT64_FAKE == 1
+    datasize = snp____rintf
+      (data, 79, "%08X%08X", ui.high, ui.low);
+ #else
+    datasize = snp____rintf
+      (data, 79, "%16llX", ui);
+ #endif
+    buf.endoffset += datasize;
+  }
+#else
+ #if NETWIB_INT64_FAKE == 1
   netwib_er(netwib_buf_append_fmt(&buf, "%{uint32:8X}%{uint32:8X}",
                                   ui.high, ui.low));
-#else
+ #else
   netwib_er(netwib_buf_append_fmt(&buf, "%{uint64:16X}", ui));
+ #endif
 #endif
+
   netwib_er(netwibtest_buf_content2(&buf, wanteddecimal));
   netwib_er(netwib_buf_close(&buf));
 
@@ -708,7 +726,7 @@ netwib_err netwibtest_uint64_init(netwib_conststring hexavalue,
       high = netwib_c2_uint32_4(array[0], array[1], array[2], array[3]);
       low = netwib_c2_uint32_4(array[4], array[5], array[6], array[7]);
       if (pui != NULL) {
-        netwib_c2_uint64_set_32(*pui, high, low);
+        netwib__uint64_init_32(high, low, *pui);
       }
     }
   }
